@@ -241,4 +241,11 @@ class PycURLLibrary():
             self._logger.write(self.http_response_status(), log_level)
         else:
             self._logger.debug("No HTTP response status received", log_level)
-        
\ No newline at end of file
+        
+    def log_version(self, log_level='INFO'):
+        """
+        Logs the PycURLLibrary Version.
+
+        Specify `log_level` (default: "INFO") to set the log level.
+        """
+        self._logger.write("PycURLLibrary version %s" % (self.ROBOT_LIBRARY_VERSION), log_level)
